@@ -317,15 +317,28 @@ def _create_or_update_port(neutron_network_id, endpoint_id,
     # For the container boot from dual-net, request_address will
     # create two ports(v4 and v6 address), we should only allow one
     # for port bind.
+    # There are two cases:
+    # 1. User specifies an existing port with v4 address only.
+    #    In this case, Kuryr creates the v6 port in ipam_request_address.
+    #    We will bind the v4 port and remove the v6 port.
+    # 2. Users doesn't specify a port. In this case Kuryr creates
+    #    the v4 and v6 ports in ipam_request_address and
+    #    we will delete both ports then re-create a dual-port.
     elif num_port == 2:
+        response_port = None
         for port in filtered_ports.get('ports', []):
             port_name = port.get('name')
             if str(port_name).startswith(const.KURYR_UNBOUND_PORT):
                 app.neutron.delete_port(port['id'])
-        fixed_ips = (
-            lib_utils.get_dict_format_fixed_ips_from_kv_format(fixed_ips))
-        response_port = _create_port(endpoint_id, neutron_network_id,
-                                     interface_mac, fixed_ips)
+            else:
+                port_driver = get_driver(port)
+                response_port = port_driver.update_port(port, endpoint_id,
+                                                        interface_mac)
+        if not response_port:
+            fixed_ips = (
+                lib_utils.get_dict_format_fixed_ips_from_kv_format(fixed_ips))
+            response_port = _create_port(endpoint_id, neutron_network_id,
+                                         interface_mac, fixed_ips)
     else:
         raise exceptions.DuplicatedResourceException(
             "Multiple ports exist for the cidrs {0} and {1}"
@@ -511,7 +524,6 @@ def _update_existing_port(existing_port, fixed_ip, mac_address):
         updated_port = {
             'name': const.NEUTRON_UNBOUND_PORT,
             'admin_state_up': True,
-            'binding:host_id': lib_utils.get_hostname(),
         }
         if mac_address:
             updated_port['mac_address'] = mac_address
@@ -1704,8 +1716,6 @@ def ipam_request_address():
                     'admin_state_up': True,
                     'network_id': neutron_network_id,
                 }
-                if req_mac_address:
-                    port['mac_address'] = req_mac_address
                 fixed_ips = port['fixed_ips'] = []
                 fixed_ip = {'subnet_id': subnet['id']}
                 filtered_ports = []
@@ -1718,6 +1728,7 @@ def ipam_request_address():
                         fixed_ips=fixed_ip_existing).get('ports', [])
                 if not filtered_ports:
                     filtered_ports = app.neutron.list_ports(
+                        fixed_ips='subnet_id=%s' % subnet['id'],
                         mac_address=req_mac_address).get('ports', [])
 
                 num_ports = len(filtered_ports)
