@@ -668,7 +668,6 @@ class TestKuryrIpam(base.TestKuryrBase):
             'name': const.KURYR_UNBOUND_PORT,
             'admin_state_up': True,
             'network_id': neutron_network_id,
-            'mac_address': fake_mac_address,
         }
         fixed_ips = port_request['fixed_ips'] = []
         fixed_ip = {'subnet_id': subnet_v4_id}
@@ -776,7 +775,6 @@ class TestKuryrIpam(base.TestKuryrBase):
             'name': const.KURYR_UNBOUND_PORT,
             'admin_state_up': True,
             'network_id': neutron_network_id,
-            'mac_address': fake_mac_address,
         }
         fixed_ips = port_request['fixed_ips'] = []
         fixed_ip = {'subnet_id': subnet_v4_id,
@@ -800,7 +798,9 @@ class TestKuryrIpam(base.TestKuryrBase):
             subnetpool_id=fake_kuryr_subnetpool_id)
         mock_list_ports.assert_has_calls([
             mock.call(fixed_ips=fixed_ip_existing),
-            mock.call(mac_address=fake_mac_address)])
+            mock.call(
+                mac_address=fake_mac_address,
+                fixed_ips='subnet_id=%s' % fake_v4_subnet['subnet']['id'])])
         mock_create_port.assert_called_with({'port': port_request})
         if mock_app.tag_ext:
             mock_port_add_tag.assert_called()
@@ -879,7 +879,6 @@ class TestKuryrIpam(base.TestKuryrBase):
         update_port = {
             'name': const.NEUTRON_UNBOUND_PORT,
             'admin_state_up': True,
-            'binding:host_id': lib_utils.get_hostname(),
             'mac_address': requested_mac_address,
         }
         mock_update_port.return_value = fake_port
@@ -995,7 +994,6 @@ class TestKuryrIpam(base.TestKuryrBase):
         update_port = {
             'name': const.NEUTRON_UNBOUND_PORT,
             'admin_state_up': True,
-            'binding:host_id': lib_utils.get_hostname(),
             'mac_address': requested_mac_address,
         }
         mock_update_port.return_value = fake_port
@@ -1032,8 +1030,10 @@ class TestKuryrIpam(base.TestKuryrBase):
             mock.call(subnetpool_id=fake_kuryr_subnetpool_id),
             mock.call(subnetpool_id=fake_kuryr_subnetpool_v6_id)])
         mock_list_ports.assert_has_calls([
-            mock.call(mac_address=requested_mac_address),
-            mock.call(mac_address=requested_mac_address)])
+            mock.call(mac_address=requested_mac_address,
+                      fixed_ips='subnet_id=%s' % subnet_v4_id),
+            mock.call(mac_address=requested_mac_address,
+                      fixed_ips='subnet_id=%s' % subnet_v6_id)])
         mock_update_port.assert_called_with(fake_neutron_port_id,
             {'port': update_port})
         if mock_app.tag_ext:
@@ -1104,7 +1104,6 @@ class TestKuryrIpam(base.TestKuryrBase):
             'name': const.KURYR_UNBOUND_PORT,
             'admin_state_up': True,
             'network_id': neutron_network_id,
-            'mac_address': fake_mac_address,
         }
         port_request['fixed_ips'] = []
         fixed_ip = {'subnet_id': neutron_subnet_v4_id}
@@ -1262,7 +1261,6 @@ class TestKuryrIpam(base.TestKuryrBase):
             'name': const.KURYR_UNBOUND_PORT,
             'admin_state_up': True,
             'network_id': neutron_network_id,
-            'mac_address': fake_mac_address,
         }
         port_request['fixed_ips'] = []
         fixed_ip = {'subnet_id': neutron_subnet_v4_id}
